Mixed-up Code Questions
-----------------------
.. selectquestion:: functEx1muc_v2_sq
   :fromid: functEx1muc_v2, functEx1muc_v2_ac
   :toggle:


.. selectquestion:: functEx2muc_sq
   :fromid: functEx2muc, functEx2muc_ac
   :toggle:


.. selectquestion:: functEx3muc_sq
   :fromid: functEx3muc, functEx3muc_ac
   :toggle:


.. selectquestion:: functEx4muc_v5_sq
   :fromid: functEx4muc_v5, functEx4muc_v5_ac
   :toggle:



.. selectquestion:: functEx5muc_v2_sq
   :fromid: functEx5muc_v2, functEx5muc_v2_ac
   :toggle:



.. selectquestion:: functEx6muc_sq
   :fromid: functEx6muc, functEx6muc_ac
   :toggle:



.. selectquestion:: functEx7muc_v2_sq
   :fromid: functEx7muc_v2, functEx7muc_v2_ac
   :toggle:


.. selectquestion:: functEx8muc_sq
   :fromid: functEx8muc, functEx8muc_ac
   :toggle:


.. selectquestion:: functEx9muc_sq
   :fromid: functEx9muc, functEx9muc_ac
   :toggle:


.. selectquestion:: functEx10muc_sq
   :fromid: functEx10muc, functEx10muc_ac
   :toggle:


.. selectquestion:: functEx11muc_sq
   :fromid: functEx11muc, functEx11muc_ac
   :toggle:


.. selectquestion:: functEx12muc_v2_sq
   :fromid: functEx12muc_v2, functEx12muc_v2_ac
   :toggle:
